/* translators: %s: Element type title. */
__( 'Edit %s', 'elementor' );
__( 'General', 'elementor' );
__( 'Style', 'elementor' );
__( 'Show less', 'elementor' );
__( 'Show more', 'elementor' );
__( 'Search dynamic tag', 'elementor' );
__( 'Sorry, nothing matched', 'elementor' );
__( 'Clear the filters', 'elementor' );
__( 'and try again.', 'elementor' );
__( 'Remove dynamic value', 'elementor' );
__( 'Dynamic Tags', 'elementor' );
__( 'Settings', 'elementor' );
__( 'Select Image', 'elementor' );
__( 'Upload Image', 'elementor' );
__( 'Size', 'elementor' );
__( 'Width', 'elementor' );
__( 'Height', 'elementor' );
__( 'Min. Width', 'elementor' );
__( 'Min. Height', 'elementor' );
__( 'Max. Width', 'elementor' );
__( 'Max. Height', 'elementor' );
__( 'Word Spacing', 'elementor' );
__( 'Typography', 'elementor' );
__( 'Capitalize', 'elementor' );
__( 'Uppercase', 'elementor' );
__( 'Lowercase', 'elementor' );
__( 'Transform', 'elementor' );
__( 'Style', 'elementor' );
__( 'Text Color', 'elementor' );
__( 'Left', 'elementor' );
__( 'Center', 'elementor' );
__( 'Right', 'elementor' );
__( 'Justify', 'elementor' );
__( 'Alignment', 'elementor' );
__( 'Letter Spacing', 'elementor' );
__( 'Light - 400', 'elementor' );
__( 'Regular - 500', 'elementor' );
__( 'Semi Bold - 600', 'elementor' );
__( 'Bold - 700', 'elementor' );
__( 'Black - 900', 'elementor' );
__( 'Font Weight', 'elementor' );
__( 'Font Size', 'elementor' );
__( 'Spacing', 'elementor' );
__( 'Padding', 'elementor' );
__( 'Margin', 'elementor' );
__( 'Link Inputs', 'elementor' );
__( 'Top', 'elementor' );
__( 'Right', 'elementor' );
__( 'Bottom', 'elementor' );
__( 'Left', 'elementor' );
__( 'Z-Index', 'elementor' );
__( 'Position', 'elementor' );